There are three different modules: (1) model fitting and selection using a set of the most commonly used equations describing developmental responses to temperature helped by already existing R packages ('rTPC') and nonlinear regression model functions from 'nls.multstart' (Padfield et al. 2021, tools:::Rd_expr_doi("10.1111/2041-210X.13585")), with visualization of model predictions to guide ecological criteria for model selection; (2) calculation of suitability thermal limits, which consist on a temperature interval delimiting the optimal performance zone or suitability; and (3) climatic data extraction and visualization inspired on previous research (Taylor et al. 2019, tools:::Rd_expr_doi("10.1111/1365-2664.13455")), with either exportable rasters, static map images or html, interactive maps.
Maintainer: Darío San-Segundo Molina dario.ssm2@gmail.com (ORCID) [copyright holder]
Authors:
A. Márcia Barbosa (ORCID) [copyright holder]
Antonio Jesús Pérez-Luque ajpelu@gmail.com (ORCID) [copyright holder]
Francisco Rodríguez-Sánchez f.rodriguez.sanc@gmail.com (ORCID) [copyright holder]
Useful links: